@@ -1,3 +1,6 @@
+// Allow `&Matrix` in function signatures.
+#![allow(clippy::ptr_arg)]
+
 use ff::{Field, ScalarEngine};
 
 /// Matrix functions here are, at least for now, quick and dirty — intended only to support precomputation of poseidon optimization.
@@ -13,16 +16,16 @@ pub fn rows<T>(matrix: &Matrix<T>) -> usize {
 /// Panics if `matrix` is not actually a matrix. So only use any of these functions on well-formed data.
 /// Only use during constant calculation on matrices known to have been constructed correctly.
 fn columns<T>(matrix: &Matrix<T>) -> usize {
-    if matrix.len() > 0 {
-        let length = matrix[0].len();
-        for i in 1..rows(matrix) {
-            if matrix[i].len() != length {
+    if matrix.is_empty() {
+        0
+    } else {
+        let column_length = matrix[0].len();
+        for row in matrix {
+            if row.len() != column_length {
                 panic!("not a matrix");
             }
         }
-        length
-    } else {
-        0
+        column_length
     }
 }
 
@@ -38,7 +41,7 @@ fn scalar_mul<E: ScalarEngine>(scalar: Scalar<E>, matrix: &Matrix<Scalar<E>>) ->
         .map(|row| {
             row.iter()
                 .map(|val| {
-                    let mut prod = scalar.clone();
+                    let mut prod = scalar;
                     prod.mul_assign(val);
                     prod
                 })
@@ -50,7 +53,7 @@ fn scalar_mul<E: ScalarEngine>(scalar: Scalar<E>, matrix: &Matrix<Scalar<E>>) ->
 fn scalar_vec_mul<E: ScalarEngine>(scalar: Scalar<E>, vec: &[Scalar<E>]) -> Vec<Scalar<E>> {
     vec.iter()
         .map(|val| {
-            let mut prod = scalar.clone();
+            let mut prod = scalar;
             prod.mul_assign(val);
             prod
         })
@@ -67,14 +70,14 @@ pub fn mat_mul<E: ScalarEngine>(
 
     let b_t = transpose::<E>(b);
 
-    let mut res = Vec::with_capacity(rows(a));
-    for i in 0..rows(a) {
-        let mut row = Vec::with_capacity(columns(b));
-        for j in 0..columns(b) {
-            row.push(vec_mul::<E>(&a[i], &b_t[j]));
-        }
-        res.push(row);
-    }
+    let res = a
+        .iter()
+        .map(|input_row| {
+            b_t.iter()
+                .map(|transposed_column| vec_mul::<E>(&input_row, &transposed_column))
+                .collect()
+        })
+        .collect();
 
     Some(res)
 }
@@ -83,7 +86,7 @@ fn vec_mul<E: ScalarEngine>(a: &[Scalar<E>], b: &[Scalar<E>]) -> Scalar<E> {
     a.iter()
         .zip(b)
         .fold(Scalar::<E>::zero(), |mut acc, (v1, v2)| {
-            let mut tmp = v1.clone();
+            let mut tmp = *v1;
             tmp.mul_assign(&v2);
             acc.add_assign(&tmp);
             acc
@@ -94,7 +97,7 @@ pub fn vec_add<E: ScalarEngine>(a: &[Scalar<E>], b: &[Scalar<E>]) -> Vec<Scalar<
     a.iter()
         .zip(b.iter())
         .map(|(a, b)| {
-            let mut res = a.clone();
+            let mut res = *a;
             res.add_assign(b);
             res
         })
@@ -105,7 +108,7 @@ pub fn vec_sub<E: ScalarEngine>(a: &[Scalar<E>], b: &[Scalar<E>]) -> Vec<Scalar<
     a.iter()
         .zip(b.iter())
         .map(|(a, b)| {
-            let mut res = a.clone();
+            let mut res = *a;
             res.sub_assign(b);
             res
         })
@@ -157,6 +160,7 @@ pub fn apply_matrix<E: ScalarEngine>(m: &Matrix<Scalar<E>>, v: &[Scalar<E>]) ->
     result
 }
 
+#[allow(clippy::needless_range_loop)]
 pub fn transpose<E: ScalarEngine>(matrix: &Matrix<Scalar<E>>) -> Matrix<Scalar<E>> {
     let size = rows(matrix);
     let mut new = Vec::with_capacity(size);
@@ -170,6 +174,7 @@ pub fn transpose<E: ScalarEngine>(matrix: &Matrix<Scalar<E>>) -> Matrix<Scalar<E
     new
 }
 
+#[allow(clippy::needless_range_loop)]
 pub fn make_identity<E: ScalarEngine>(size: usize) -> Matrix<Scalar<E>> {
     let mut result = vec![vec![Scalar::<E>::zero(); size]; size];
     for i in 0..size {
@@ -205,20 +210,19 @@ pub fn minor<E: ScalarEngine>(matrix: &Matrix<Scalar<E>>, i: usize, j: usize) ->
     assert!(is_square(matrix));
     let size = rows(matrix);
     assert!(size > 0);
-    let new_size = size - 1;
-    let mut new: Matrix<Scalar<E>> = Vec::with_capacity(new_size);
-
-    for ii in 0..size {
-        if ii != i {
-            let mut row = Vec::with_capacity(new_size);
-            for jj in 0..size {
-                if jj != j {
-                    row.push(matrix[ii][jj]);
-                }
+    let new = matrix
+        .iter()
+        .enumerate()
+        .filter_map(|(ii, row)| {
+            if ii == i {
+                None
+            } else {
+                let mut new_row = row.clone();
+                new_row.remove(j);
+                Some(new_row)
             }
-            new.push(row);
-        }
-    }
+        })
+        .collect();
     assert!(is_square(&new));
     new
 }
@@ -252,7 +256,7 @@ fn eliminate<E: ScalarEngine>(
             // Value is already eliminated.
             result.push(row.to_vec());
         } else {
-            let mut factor = val.clone();
+            let mut factor = val;
             factor.mul_assign(&inv_pivot);
 
             let scaled_pivot = scalar_vec_mul::<E>(factor, &pivot);
